bayespy.inference.vmp.nodes.wishart.WishartDistribution.compute_moments_and_cgf
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartDistribution.compute_moments_and_cgf